@@ -1,4 +1,4 @@
-__version__ = '0.1.6'
+__version__ = '0.2.0'
 __app_name__ = 'todo'
 
 from dataclasses import dataclass
@@ -7,7 +7,7 @@ from typing import Any
 
 try:
     from logging_utils_tddschn import get_logger
-    logger, _ = get_logger(__app_name__)
+    logger, _DEBUG = get_logger(__app_name__)
 except:
     import logging
     from logging import NullHandler
